@@ -2,15 +2,22 @@ from flask import request, g, current_app
 from werkzeug.exceptions import Unauthorized
 from functools import wraps
 from bouncer import Ability
+from bouncer.constants import *
+
+
 
 
 def bounce(action, subject):
     current_user = get_current_user()
     ability = Ability(current_user)
+    ability.alias_actions = current_app.bouncer.alias_actions
     if ability.cannot(action, subject):
         msg = "{} does not have {} access to {}".format(current_user, action, subject)
         raise Unauthorized(msg)
 
+#alais
+ensure = bounce
+
 
 def get_current_user():
     if hasattr(g, 'current_user'):
@@ -47,6 +54,25 @@ class Bouncer(object):
 
         self.authorization_method_callback = None
 
+        self._alias_actions = self.default_alias_actions
+
+
+    @property
+    def alias_actions(self):
+        return self._alias_actions
+
+    @alias_actions.setter
+    def alias_actions(self, value):
+        """if you want to override your actions"""
+        self._alias_actions = value
+
+    def default_alias_actions(self):
+        return {
+            READ: [INDEX, SHOW, GET],
+            CREATE: [NEW, PUT, POST],
+            UPDATE: [EDIT, PATCH]
+        }
+
     def bounce(self, *classy_routes):
         if self.flask_classy_classes is None:
             self.flask_classy_classes = list()
